@@ -26,6 +26,7 @@ class ThermoBuilder(Builder):
         query: Optional[Dict] = None,
         compatibility: Optional[List[Compatibility]] = None,
         num_phase_diagram_eles: Optional[int] = None,
+        chunk_size: int = 1000,
         **kwargs,
     ):
         """
@@ -43,6 +44,7 @@ class ThermoBuilder(Builder):
                 to ensure energies are compatible
             num_phase_diagram_eles (int): Maximum number of elements to use in phase diagram construction
                 for data within the separate phase_diagram collection
+            chunk_size (int): Size of chemsys chunks to process at any one time.
         """
 
         self.materials = materials
@@ -52,6 +54,7 @@ class ThermoBuilder(Builder):
         self.oxidation_states = oxidation_states
         self.phase_diagram = phase_diagram
         self.num_phase_diagram_eles = num_phase_diagram_eles
+        self.chunk_size = chunk_size
         self._completed_tasks: Set[str] = set()
         self._entries_cache: Dict[str, List[ComputedStructureEntry]] = defaultdict(list)
 
@@ -91,7 +94,7 @@ class ThermoBuilder(Builder):
 
             targets.append(phase_diagram)  # type: ignore
 
-        super().__init__(sources=sources, targets=targets, **kwargs)
+        super().__init__(sources=sources, targets=targets, chunk_size=chunk_size, **kwargs)
 
     def ensure_indexes(self):
         """
